from __future__ import unicode_literals

from django.views.generic import TemplateView
from django.shortcuts import redirect
from django.conf import settings


class DemoView(TemplateView):
    """Demo view."""

    template_name = "evotecore/demo.html"


class HomepageView(TemplateView):
    """Homepage view."""
    template_name = "evotecore/index.html"

    def get(self, request, *args, **kwargs):
        if request.user.is_authenticated():
            return redirect(settings.LOGIN_REDIRECT_URL)
        return super(HomepageView, self).get(request, *args, **kwargs)


class ErrorBaseView(TemplateView):
    """ Error base view """
    error = None

    @classmethod
    def get_view_rendered(cls, error_code):
        view = cls.as_view(error=error_code)

        def view_function(request):
            return view(request).render()

        return view_function

    def get(self, request, *args, **kwargs):
        response = super(ErrorBaseView, self).get(request, *args, **kwargs)
        response.status_code = self.error
        return response

    def get_context_data(self, **kwargs):
        context = super(ErrorBaseView, self).get_context_data(**kwargs)
        context.update({
            'template': 'evotecore/includes/errors/' + str(self.error) +
            ".html"
        })
        return context
