from __future__ import unicode_literals

import logging

# needed when logging_config doesn't start with logging.config
import logging.config # noqa
from copy import copy

from django.conf import settings
from django.utils.log import AdminEmailHandler
from django.views.debug import ExceptionReporter
from django.core.mail import EmailMultiAlternatives


class LogsEmailHandler(AdminEmailHandler):

    def emit(self, record):
        try:
            request = record.request
        except Exception:
            request = None

        hostname = settings.ALLOWED_HOSTS.pop()
        subject = '[%s] %s : %s' % (
            hostname,
            record.levelname,
            record.getMessage()
        )
        subject = self.format_subject(subject)

        # Since we add a nicely formatted traceback on our own, create a copy
        # of the log record without the exception data.
        no_exc_record = copy(record)
        no_exc_record.exc_info = None
        no_exc_record.exc_text = None

        if record.exc_info:
            exc_info = record.exc_info
        else:
            exc_info = (None, record.getMessage(), None)

        reporter = ExceptionReporter(request, is_email=True, *exc_info)
        message = "%s\n\n%s" % (self.format(no_exc_record),
                                reporter.get_traceback_text())

        html_message = None
        if self.include_html:
            html_message = reporter.get_traceback_html()

        self.send_mail(
            subject, message,
            fail_silently=True, html_message=html_message
        )

    def send_mail(self, subject, message, *args, **kwargs):
        html_message = kwargs.pop('html_message')
        mail = EmailMultiAlternatives(
            subject, message, settings.SERVER_EMAIL,
            [a[1] for a in settings.EVOTELOG_MAIL_LIST],
        )
        mail.attach_alternative(html_message, "text/html")
        mail.send(*args, **kwargs)
